@@ -14,11 +14,12 @@ use Plack::Util::Accessor qw(
     name
     regex
     type
+    coerce
 );
 
 use Raisin::Util;
 
-my @ATTRIBUTES = qw(name type default regex desc);
+my @ATTRIBUTES = qw(name type default regex desc coerce);
 my @LOCATIONS = qw(path formData body header query);
 
 sub new {
@@ -54,6 +55,8 @@ sub _parse {
         }
     }
 
+    $self->{coerce} = defined($spec->{coerce}) ? $spec->{coerce} : 1;
+
     return 1;
 }
 
@@ -111,8 +114,17 @@ sub validate {
 
     # Type check
     eval {
+        if ($self->type->has_coercion && $self->coerce) {
+            eval {
+                $$ref_value = $self->type->coerce($$ref_value);
+            } or do {
+                Raisin::log(warn => 'Param `%s` failed coercion with value "%s"',
+                    $self->name, $$ref_value);
+                return;
+            };
+        }
+
         if ($self->type->isa('Moose::Meta::TypeConstraint')) {
-            # this is a Moose type constraint
             $self->type->assert_valid($$ref_value);
         }
         else {
@@ -163,6 +175,12 @@ Raisin::Param - Parameter class for Raisin.
 
 Parameter class for L<Raisin>. Validates request paramters.
 
+=head3 coerce
+
+Returns coerce flag. If C<true> attempt to coerce a value will be made at validate stage.
+
+By default set to C<true>.
+
 =head3 default
 
 Returns default value if exists or C<undef>.
